==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Statistics/language/lang-italian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_HITS","Hits");
define("_BROWSERS","Browser");
define("_OPERATINGSYS","Sistema Operativo");
define("_UNKNOWN","Sconosciuto");
define("_OTHER","Altro / Sconosciuto");
define("_MISCSTATS","Miscelaneous Statistiche");
define("_REGUSERS","Utenti Registrati:");
define("_ACTIVEAUTHORS","Autori Attivi:");
define("_STORIESPUBLISHED","Articoli Pubblicati:");
define("_SACTIVETOPICS","Argomenti Attivi:");
define("_COMMENTSPOSTED","Commenti Postati:");
define("_SSPECIALSECT","Sezioni Speciali:");
define("_ARTICLESSEC","Articoli nelle Sezioni:");
define("_LINKSINLINKS","Siti nella Directory:");
define("_LINKSCAT","Categorie nella Directory:");
define("_NEWSWAITING","Articoli in Attesa di essere Pubblicati:");
define("_NUKEVERSION","PHP-Nuke Versione:");
define("_SEARCHENGINES","Motori di Ricerca");
define("_BOTS","Robots/Spiders");
define("_STATS","Accessi Statistiche");
define("_RETURNBASICSTATS","Return to Basic Statistics");
define("_BACKTODETSTATS","Back to Detailed Statistics");
define("_BACKTOMAIN","Back to Main");
define("_TODAYIS","Today is");
define("_MOSTMONTH","Busiest Month");
define("_MOSTDAY","Busiest Day");
define("_MOSTHOUR","Busiest Hour");
define("_YEARLYSTATS","Yearly Stats");
define("_MONTLYSTATS","Montly Stats for");
define("_SPAGESVIEWS","Page Views");
define("_DAILYSTATS","Daily Stats for");
define("_HOURLYSTATS","Hourly Stats for");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Statistics/language/lang-italian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_HITS","Hits");
define("_BROWSERS","Browser");
define("_OPERATINGSYS","Sistema Operativo");
define("_UNKNOWN","Sconosciuto");
define("_OTHER","Altro / Sconosciuto");
define("_MISCSTATS","Miscelaneous Statistiche");
define("_REGUSERS","Utenti Registrati:");
define("_ACTIVEAUTHORS","Autori Attivi:");
define("_STORIESPUBLISHED","Articoli Pubblicati:");
define("_SACTIVETOPICS","Argomenti Attivi:");
define("_COMMENTSPOSTED","Commenti Postati:");
define("_SSPECIALSECT","Sezioni Speciali:");
define("_ARTICLESSEC","Articoli nelle Sezioni:");
define("_LINKSINLINKS","Siti nella Directory:");
define("_LINKSCAT","Categorie nella Directory:");
define("_NEWSWAITING","Articoli in Attesa di essere Pubblicati:");
define("_NUKEVERSION","PHP-Nuke Versione:");
define("_SEARCHENGINES","Motori di Ricerca");
define("_BOTS","Robots/Spiders");
define("_STATS","Accessi Statistiche");
define("_RETURNBASICSTATS","Return to Basic Statistics");
define("_BACKTODETSTATS","Back to Detailed Statistics");
define("_BACKTOMAIN","Back to Main");
define("_TODAYIS","Today is");
define("_MOSTMONTH","Busiest Month");
define("_MOSTDAY","Busiest Day");
define("_MOSTHOUR","Busiest Hour");
define("_YEARLYSTATS","Yearly Stats");
define("_MONTLYSTATS","Montly Stats for");
define("_SPAGESVIEWS","Page Views");
define("_DAILYSTATS","Daily Stats for");
define("_HOURLYSTATS","Hourly Stats for");

?>
